@@ -1,40 +1,43 @@
-/*    motion.h
+/*   This file is part of Motion.
  *
- *    Include file for motion.c
- *      Copyright 2000 by Jeroen Vreeken (pe1rxq@amsat.org)
- *      This software is distributed under the GNU public license version 2
- *      See also the file 'COPYING'.
+ *   Motion is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, either version 2 of the License, or
+ *   (at your option) any later version.
  *
+ *   Motion is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with Motion.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
+/*
+ *  motion.h
+ *    Headers associated with functions in the motion.c module.
+ *    Copyright 2000 by Jeroen Vreeken (pe1rxq@amsat.org)
  */
 
 #ifndef _INCLUDE_MOTION_H
 #define _INCLUDE_MOTION_H
 
-/* Forward declarations, used in functional definitions of headers */
+/* Forward declarations of structs */
 struct images;
 struct image_data;
+struct rtsp_context;
+struct ffmpeg;
 
 #include "config.h"
 
 /* Includes */
-#if defined(HAVE_MYSQL) || defined(HAVE_MARIADB)
-#include <mysql.h>
-#endif
-
-#ifdef HAVE_SQLITE3
-#include <sqlite3.h>
-#endif
-
-#ifdef HAVE_PGSQL
-#include <libpq-fe.h>
-#endif
-
-
 #include <stdio.h>
 #include <stdlib.h>
 #ifndef __USE_GNU
-#define __USE_GNU
+    #define __USE_GNU
 #endif
+#include <ctype.h>
 #include <string.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -52,45 +55,74 @@ struct image_data;
 #include <stdint.h>
 #include <pthread.h>
 #include <microhttpd.h>
+#include <regex.h>
+
 
 #if defined(HAVE_PTHREAD_NP_H)
     #include <pthread_np.h>
 #endif
 
-#include "logger.h"
-#include "conf.h"
-#include "stream.h"
+#if defined(HAVE_MYSQL)
+    #include <mysql.h>
+#endif
 
+#if defined(HAVE_MARIADB)
+    #include <mysql.h>
+#endif
+
+#ifdef HAVE_SQLITE3
+    #include <sqlite3.h>
+#endif
+
+#ifdef HAVE_PGSQL
+    // avoid libpq-fe.h collision with motion.h #define CONNECTION_OK (below)
+    #define CONNECTION_OK PGSQL_CONNECTION_OK
+    #include <libpq-fe.h>
+    // avoid redefinition warning for motion.h #define CONNECTION_OK below
+    #undef CONNECTION_OK
+#endif
+
+#ifdef HAVE_FFMPEG
+
+    #define MYFFVER (LIBAVFORMAT_VERSION_MAJOR * 1000)+LIBAVFORMAT_VERSION_MINOR
+
+    #include <errno.h>
+    #include <libavformat/avformat.h>
+    #include <libavutil/imgutils.h>
+    #include <libavutil/mathematics.h>
+    #include <libavdevice/avdevice.h>
+    #include <libavcodec/avcodec.h>
+    #include <libavformat/avio.h>
+    #include <libavutil/avutil.h>
+    #include <libswscale/swscale.h>
+    #if (MYFFVER >= 57083)
+        #include "libavutil/hwcontext.h"
+    #endif
+#else
+    #define MYFFVER 0
+#endif
+
+#ifndef TRUE
+    #define TRUE 1
+#endif
+
+#ifndef FALSE
+    #define FALSE 0
+#endif
+
+/* Due to the pointer magic method of conf, the conf.h and track.h must stay in here */
+#include "conf.h"
 #include "track.h"
-#include "netcam.h"
-#include "netcam_rtsp.h"
-#include "ffmpeg.h"
 
 #ifdef HAVE_MMAL
-#include "mmalcam.h"
+    #include "mmalcam.h"
 #endif
 
 
-/**
- * ATTRIBUTE_UNUSED:
- *
- * Macro used to signal to GCC unused function parameters
- */
-#ifdef __GNUC__
-#ifdef HAVE_ANSIDECL_H
-#include <ansidecl.h>
-#endif
-#ifndef ATTRIBUTE_UNUSED
-#define ATTRIBUTE_UNUSED __attribute__((unused))
-#endif
-#else
-#define ATTRIBUTE_UNUSED
-#endif
-
 /*
- *  The macro below defines a version of sleep using nanosleep
- * If a signal such as SIG_CHLD interrupts the sleep we just continue sleeping
- */
+*  The macro below defines a version of sleep using nanosleep
+* If a signal such as SIG_CHLD interrupts the sleep we just continue sleeping
+*/
 #define SLEEP(seconds, nanoseconds) {              \
                 struct timespec tv;                \
                 tv.tv_sec = (seconds);             \
@@ -98,8 +130,6 @@ struct image_data;
                 while (nanosleep(&tv, &tv) == -1); \
         }
 
-#define DEF_PALETTE             17
-
 /* Default picture settings */
 #define DEF_WIDTH              640
 #define DEF_HEIGHT             480
@@ -112,19 +142,15 @@ struct image_data;
 /* Minimum time between two 'actions' (email, sms, external) */
 #define DEF_EVENT_GAP            60  /* 1 minutes */
 
-#define DEF_INPUT               -1
 #define DEF_VIDEO_DEVICE         "/dev/video0"
 
 #define THRESHOLD_TUNE_LENGTH  256
 
 #define MISSING_FRAMES_TIMEOUT  30  /* When failing to get picture frame from camera
-                                       we reuse the previous frame until
-                                       MISSING_FRAMES_TIMEOUT seconds has passed
-                                       and then we show a grey image instead
-                                     */
-
-#define WATCHDOG_TMO            30   /* 30 sec max motion_loop interval */
-#define WATCHDOG_KILL          -10   /* 10 sec grace period before calling thread cancel */
+                                    we reuse the previous frame until
+                                    MISSING_FRAMES_TIMEOUT seconds has passed
+                                    and then we show a grey image instead
+                                    */
 
 #define CONNECTION_KO           "Lost connection"
 #define CONNECTION_OK           "Connection OK"
@@ -146,6 +172,7 @@ struct image_data;
 #define IMAGE_TYPE_JPEG        0
 #define IMAGE_TYPE_PPM         1
 #define IMAGE_TYPE_WEBP        2
+#define IMAGE_TYPE_GREY        3
 
 /* Filetype defines */
 #define FTYPE_IMAGE            1
@@ -181,12 +208,12 @@ struct image_data;
 
 
 /*
- * Structure to hold images information
- * The idea is that this should have all information about a picture e.g. diffs, timestamp etc.
- * The exception is the label information, it uses a lot of memory
- * When the image is stored all texts motion marks etc. is written to the image
- * so we only have to send it out when/if we want.
- */
+* Structure to hold images information
+* The idea is that this should have all information about a picture e.g. diffs, timestamp etc.
+* The exception is the label information, it uses a lot of memory
+* When the image is stored all texts motion marks etc. is written to the image
+* so we only have to send it out when/if we want.
+*/
 
 /* A image can have detected motion in it, but dosn't trigger an event, if we use minimum_motion_frames */
 #define IMAGE_MOTION     1
@@ -206,29 +233,24 @@ enum CAMERA_TYPE {
 };
 
 enum WEBUI_LEVEL{
-  WEBUI_LEVEL_ALWAYS     = 0,
-  WEBUI_LEVEL_LIMITED    = 1,
-  WEBUI_LEVEL_ADVANCED   = 2,
-  WEBUI_LEVEL_RESTRICTED = 3,
-  WEBUI_LEVEL_NEVER      = 99
+WEBUI_LEVEL_ALWAYS     = 0,
+WEBUI_LEVEL_LIMITED    = 1,
+WEBUI_LEVEL_ADVANCED   = 2,
+WEBUI_LEVEL_RESTRICTED = 3,
+WEBUI_LEVEL_NEVER      = 99
 };
 
-struct vdev_usrctrl_ctx {
-    char          *ctrl_name;       /* The name or description of the ID as requested by user*/
-    int            ctrl_value;      /* The value that the user wants the control set to*/
+struct params_item_ctx {
+    char    *param_name;       /* The name or description of the ID as requested by user*/
+    char    *param_value;      /* The value that the user wants the control set to*/
 };
 
-struct vdev_context {
-    /* As v4l2 and bktr get rewritten, put thread specific items here
-     * Rather than use conf options directly, copy from conf to here
-     * to handle cross thread webui changes which could cause problems
-     */
-    struct vdev_usrctrl_ctx *usrctrl_array;     /*Array of the controls the user specified*/
-    int usrctrl_count;                          /*Count of the controls the user specified*/
-    int update_parms;                           /*Bool for whether to update the parameters on the device*/
+struct params_context {
+    struct params_item_ctx *params_array;     /*Array of the controls the user specified*/
+    int params_count;                         /*Count of the controls the user specified*/
+    int update_params;                        /*Bool for whether to update the parameters on the device*/
 };
 
-
 struct image_data {
     unsigned char *image_norm;
     unsigned char *image_high;
@@ -239,9 +261,9 @@ struct image_data {
     int shot;                   /* Sub second timestamp count */
 
     /*
-     * Movement center to img center distance
-     * Note: Dist is calculated distX*distX + distY*distY
-     */
+    * Movement center to img center distance
+    * Note: Dist is calculated distX*distX + distY*distY
+    */
     unsigned long cent_dist;
 
     unsigned int flags;         /* Se IMAGE_* defines */
@@ -259,37 +281,30 @@ struct stream_data {
 };
 
 /*
- * DIFFERENCES BETWEEN imgs.width, conf.width AND rotate_data.cap_width
- * (and the corresponding height values, of course)
- * ===========================================================================
- * Location      Purpose
- *
- * conf          The values in conf reflect width and height set in the
- *               configuration file. These can be set via http remote control,
- *               but they are not used internally by Motion, so it won't break
- *               anything. These values are transferred to imgs in vid_start.
- *
- * imgs          The values in imgs are the actual output dimensions. Normally
- *               the output dimensions are the same as the capture dimensions,
- *               but for 90 or 270 degrees rotation, they are not. E.g., if
- *               you capture at 320x240, and rotate 90 degrees, the output
- *               dimensions are 240x320.
- *               These values are set from the conf values in vid_start, or
- *               from the first JPEG image in netcam_start. For 90 or 270
- *               degrees rotation, they are swapped in rotate_init.
- *
- * rotate_data   The values in rotate_data are named cap_width and cap_height,
- *               and contain the capture dimensions. The difference between
- *               capture and output dimensions is explained above.
- *               These values are set in rotate_init.
- */
-
-/* date/time drawing, draw.c */
-int draw_text(unsigned char *image,
-              int width, int height,
-              int startx, int starty,
-              const char *text, int factor);
-int initialize_chars(void);
+* DIFFERENCES BETWEEN imgs.width, conf.width AND rotate_data.cap_width
+* (and the corresponding height values, of course)
+* ===========================================================================
+* Location      Purpose
+*
+* conf          The values in conf reflect width and height set in the
+*               configuration file. These can be set via http remote control,
+*               but they are not used internally by Motion, so it won't break
+*               anything. These values are transferred to imgs in vid_start.
+*
+* imgs          The values in imgs are the actual output dimensions. Normally
+*               the output dimensions are the same as the capture dimensions,
+*               but for 90 or 270 degrees rotation, they are not. E.g., if
+*               you capture at 320x240, and rotate 90 degrees, the output
+*               dimensions are 240x320.
+*               These values are set from the conf values in vid_start, or
+*               from the first JPEG image in netcam_start. For 90 or 270
+*               degrees rotation, they are swapped in rotate_init.
+*
+* rotate_data   The values in rotate_data are named cap_width and cap_height,
+*               and contain the capture dimensions. The difference between
+*               capture and output dimensions is explained above.
+*               These values are set in rotate_init.
+*/
 
 struct images {
     struct image_data *image_ring;    /* The base address of the image ring buffer */
@@ -358,9 +373,9 @@ struct rotdata {
 };
 
 /*
- *  These used to be global variables but now each thread will have its
- *  own context
- */
+*  These used to be global variables but now each thread will have its
+*  own context
+*/
 struct context {
     FILE *extpipe;
     int extpipe_open;
@@ -382,13 +397,13 @@ struct context {
 
     enum CAMERA_TYPE      camera_type;
     struct netcam_context *netcam;
-#ifdef HAVE_MMAL
-    struct mmalcam_context *mmalcam;
-#endif
+    #ifdef HAVE_MMAL
+        struct mmalcam_context *mmalcam;
+    #endif
     struct rtsp_context *rtsp;              /* this structure contains the context for normal RTSP connection */
     struct rtsp_context *rtsp_high;         /* this structure contains the context for high resolution RTSP connection */
 
-    struct vdev_context *vdev;              /* Structure for v4l2 and bktr device information */
+    struct params_context *vdev;            /* Structure for v4l2 and bktr device information */
 
     struct image_data *current_image;       /* Pointer to a structure where the image, diffs etc is stored */
     unsigned int new_img;
@@ -404,6 +419,10 @@ struct context {
     int diffs_last[THRESHOLD_TUNE_LENGTH];
     int smartmask_speed;
 
+    /* bktr and v4l2 params used for round robin */
+    int param_input;
+    long param_freq;
+    int param_norm;
 
     /* Commands to the motion thread */
     volatile unsigned int snapshot;    /* Make a snapshot */
@@ -436,6 +455,7 @@ struct context {
     time_t currenttime;
     time_t lasttime;
     time_t eventtime;
+    time_t movietime;
     time_t connectionlosttime;               /* timestamp from connection lost */
 
     unsigned int lastrate;
@@ -449,25 +469,36 @@ struct context {
     int pipe;
     int mpipe;
 
-    struct stream stream;
-    int stream_count;
-
     char hostname[PATH_MAX];
-    char *netcam_decoder;
 
     int sql_mask;
 
-#ifdef HAVE_SQLITE3
-    sqlite3 *database_sqlite3;
-#endif
+    #ifdef HAVE_SQLITE3
+        sqlite3 *database_sqlite3;
+    #endif
 
-#if defined(HAVE_MYSQL) || defined(HAVE_MARIADB)
-    MYSQL *database;
-#endif
+    #if defined(HAVE_MYSQL)
+        MYSQL *database_mysql;
+    #endif
 
-#ifdef HAVE_PGSQL
-    PGconn *database_pg;
-#endif
+    #if defined(HAVE_MARIADB)
+        MYSQL *database_mariadb;
+    #endif
+
+    #ifdef HAVE_PGSQL
+        PGconn *database_pgsql;
+        int    eid_db_format;          /* db event ID PQfformat() or PQgetlength() if binary */
+        #define dbeid_undetermined -1  /* sql_query_start not present or not yet executed    */
+        #define dbeid_no_return    -2  /* sql_query_start statement returned nothing         */
+        #define dbeid_not_valid    -3  /* sql_query_start statement returned invalid value:  */
+                                       /* multiple values or value not a positive integer    */
+        #define dbeid_unk_format   -4  /* PGgetlength() returned unexpected size for bin fmt */
+        #define dbeid_use_error    -5  /* %{dbeventid} used w/ no sql_query_start return val */
+        #define dbeid_recovery     -6  /* PGSQL session in recovery after session failure    */
+        #define dbeid_rec_fail     -7  /* PQresetStart failed; keep trying                   */
+                                       /* NB: for values < -1, event ID recording is skipped */
+                                       /* unless lost session recovery or SIGHUP occur       */
+    #endif
 
     int movie_fps;
     char newfilename[PATH_MAX];
@@ -524,6 +555,9 @@ struct context {
     struct stream_data  stream_motion;  /* Copy of the image to use for web stream*/
     struct stream_data  stream_source;  /* Copy of the image to use for web stream*/
 
+    struct params_context    *webcontrol_headers;  /* Headers for webcontrol */
+    struct params_context    *stream_headers;  /* Headers for stream */
+
 
 };
 
@@ -533,17 +567,6 @@ extern FILE *ptr_logfile;
 
 /* TLS keys below */
 extern pthread_key_t tls_key_threadnr; /* key for thread number */
-
-int http_bindsock(int, int, int);
-void * mymalloc(size_t);
-void * myrealloc(void *, size_t, const char *);
-FILE * myfopen(const char *, const char *);
-int myfclose(FILE *);
-size_t mystrftime(const struct context *, char *, size_t, const char *, const struct timeval *, const char *, int);
-int create_path(const char *);
-
-void util_threadname_set(const char *abbr, int threadnbr, const char *threadname);
-void util_threadname_get(char *threadname);
-int util_check_passthrough(struct context *cnt);
+void motion_remove_pid(void);
 
 #endif /* _INCLUDE_MOTION_H */
