@@ -1,21 +1,38 @@
+/*   This file is part of Motion.
+ *
+ *   Motion is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, either version 2 of the License, or
+ *   (at your option) any later version.
+ *
+ *   Motion is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with Motion.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 /*    track.c
  *
  *    Experimental motion tracking.
  *
  *    Copyright 2000, Jeroen Vreeken
- *    This program is published under the GNU Public license
  */
 #include <math.h>
 #include "translate.h"
 #include "motion.h"
+#include "util.h"
+#include "logger.h"
 
 #ifdef HAVE_V4L2
-#if defined(HAVE_LINUX_VIDEODEV2_H)
-#include <linux/videodev2.h>
-#else
-#include <sys/videoio.h>
-#endif
-#include "pwc-ioctl.h"
+    #if defined(HAVE_LINUX_VIDEODEV2_H)
+        #include <linux/videodev2.h>
+    #else
+        #include <sys/videoio.h>
+    #endif
+    #include "pwc-ioctl.h"
 #endif
 
 
@@ -47,36 +64,38 @@ struct trackoptions track_template = {
 
 static unsigned int servo_position(struct context *cnt, unsigned int motor);
 
-static unsigned int servo_center(struct context *cnt, int xoff, int yoff ATTRIBUTE_UNUSED);
-static unsigned int stepper_center(struct context *cnt, int xoff, int yoff ATTRIBUTE_UNUSED);
+static unsigned int servo_center(struct context *cnt, int xoff, int yoff);
+static unsigned int stepper_center(struct context *cnt, int xoff, int yoff);
 static unsigned int iomojo_center(struct context *cnt, int xoff, int yoff);
 
 static unsigned int stepper_move(struct context *cnt, struct coord *cent, struct images *imgs);
-static unsigned int servo_move(struct context *cnt, struct coord *cent,
-                               struct images *imgs, unsigned int manual);
+static unsigned int servo_move(struct context *cnt, struct coord *cent
+            ,struct images *imgs, unsigned int manual);
 static unsigned int iomojo_move(struct context *cnt, int dev, struct coord *cent, struct images *imgs);
 
 #ifdef HAVE_V4L2
-static unsigned int lqos_center(struct context *cnt, int dev, int xoff, int yoff);
-static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent,
-                              struct images *imgs, unsigned int manual);
-static unsigned int uvc_center(struct context *cnt, int dev, int xoff, int yoff);
-static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
-                             struct images *imgs, unsigned int manual);
+    static unsigned int lqos_center(struct context *cnt, int dev, int xoff, int yoff);
+    static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent
+                ,struct images *imgs, unsigned int manual);
+    static unsigned int uvc_center(struct context *cnt, int dev, int xoff, int yoff);
+    static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent
+                ,struct images *imgs, unsigned int manual);
 #endif /* HAVE_V4L2 */
 
-static unsigned int generic_move(struct context *cnt, enum track_action action, unsigned int manual,
-                                 int xoff, int yoff, struct coord *cent, struct images *imgs);
+static unsigned int generic_move(struct context *cnt, enum track_action action, unsigned int manual
+            , int xoff, int yoff, struct coord *cent, struct images *imgs);
 
 
 /* Add a call to your functions here: */
-unsigned int track_center(struct context *cnt, int dev ATTRIBUTE_UNUSED,
-                          unsigned int manual, int xoff, int yoff)
+unsigned int track_center(struct context *cnt, int dev, unsigned int manual, int xoff, int yoff)
 {
     struct coord cent;
 
-    if (!manual && !cnt->track.active)
+    (void)dev;
+
+    if (!manual && !cnt->track.active) {
         return 0;
+    }
 
     if (cnt->track.type == TRACK_TYPE_STEPPER) {
         unsigned int ret;
@@ -84,21 +103,23 @@ unsigned int track_center(struct context *cnt, int dev ATTRIBUTE_UNUSED,
         if (!ret) {
             MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("internal error"));
             return 0;
+        } else {
+            return ret;
         }
-        else return ret;
     } else if (cnt->track.type == TRACK_TYPE_SERVO) {
         return servo_center(cnt, xoff, yoff);
-    }
-#ifdef HAVE_V4L2
-    else if (cnt->track.type == TRACK_TYPE_PWC)
-        return lqos_center(cnt, dev, xoff, yoff);
-    else if (cnt->track.type == TRACK_TYPE_UVC)
-        return uvc_center(cnt, dev, xoff, yoff);
-#endif
-    else if (cnt->track.type == TRACK_TYPE_IOMOJO)
+
+    #ifdef HAVE_V4L2    /*dreadful coding method imo */
+        } else if (cnt->track.type == TRACK_TYPE_PWC) {
+            return lqos_center(cnt, dev, xoff, yoff);
+        } else if (cnt->track.type == TRACK_TYPE_UVC) {
+            return uvc_center(cnt, dev, xoff, yoff);
+    #endif
+
+    } else if (cnt->track.type == TRACK_TYPE_IOMOJO) {
         return iomojo_center(cnt, xoff, yoff);
-    else if (cnt->track.type == TRACK_TYPE_GENERIC) {
-        if (cnt->track.generic_move){
+    } else if (cnt->track.type == TRACK_TYPE_GENERIC) {
+        if (cnt->track.generic_move) {
             cent.x = -cnt->track_posx;
             cent.y = -cnt->track_posy;
             return generic_move(cnt, TRACK_CENTER, manual,0 ,0 ,&cent , NULL);
@@ -114,30 +135,34 @@ unsigned int track_center(struct context *cnt, int dev ATTRIBUTE_UNUSED,
 }
 
 /* Add a call to your functions here: */
-unsigned int track_move(struct context *cnt, int dev, struct coord *cent, struct images *imgs,
-                        unsigned int manual)
+unsigned int track_move(struct context *cnt, int dev, struct coord *cent
+            , struct images *imgs, unsigned int manual)
 {
 
-    if (!manual && !cnt->track.active)
+    if (!manual && !cnt->track.active) {
         return 0;
+    }
 
-    if (cnt->track.type == TRACK_TYPE_STEPPER)
+    if (cnt->track.type == TRACK_TYPE_STEPPER) {
         return stepper_move(cnt, cent, imgs);
-    else if (cnt->track.type == TRACK_TYPE_SERVO)
+    } else if (cnt->track.type == TRACK_TYPE_SERVO) {
         return servo_move(cnt, cent, imgs, manual);
-#ifdef HAVE_V4L2
-    else if (cnt->track.type == TRACK_TYPE_PWC)
-        return lqos_move(cnt, dev, cent, imgs, manual);
-    else if (cnt->track.type == TRACK_TYPE_UVC)
-        return uvc_move(cnt, dev, cent, imgs, manual);
-#endif
-    else if (cnt->track.type == TRACK_TYPE_IOMOJO)
+
+    #ifdef HAVE_V4L2
+        } else if (cnt->track.type == TRACK_TYPE_PWC) {
+            return lqos_move(cnt, dev, cent, imgs, manual);
+        } else if (cnt->track.type == TRACK_TYPE_UVC) {
+            return uvc_move(cnt, dev, cent, imgs, manual);
+    #endif
+
+    } else if (cnt->track.type == TRACK_TYPE_IOMOJO) {
         return iomojo_move(cnt, dev, cent, imgs);
-    else if (cnt->track.type == TRACK_TYPE_GENERIC) {
-        if (cnt->track.generic_move)
+    } else if (cnt->track.type == TRACK_TYPE_GENERIC) {
+        if (cnt->track.generic_move) {
           return generic_move(cnt, TRACK_MOVE, manual, 0, 0, cent, imgs);
-        else
+        } else {
           return cnt->track.move_wait; // FIX ME. I chose to return something reasonable.
+        }
     }
 
     MOTION_LOG(WRN, TYPE_TRACK, SHOW_ERRNO
@@ -152,8 +177,8 @@ unsigned int track_move(struct context *cnt, int dev, struct coord *cent, struct
     http://www.lavrsen.dk/twiki/bin/view/Motion/MotionTrackerAPI
 ******************************************************************************/
 
-static unsigned int stepper_command(struct context *cnt, unsigned int motor,
-                                    unsigned int command, unsigned int data)
+static unsigned int stepper_command(struct context *cnt, unsigned int motor
+            , unsigned int command, unsigned int data)
 {
     char buffer[3];
     time_t timeout = time(NULL);
@@ -169,7 +194,9 @@ static unsigned int stepper_command(struct context *cnt, unsigned int motor,
         return 0;
     }
 
-    while (read(cnt->track.dev, buffer, 1) != 1 && time(NULL) < timeout + 1);
+    while (read(cnt->track.dev, buffer, 1) != 1 && time(NULL) < timeout + 1) {
+        continue;
+    }
 
     if (time(NULL) >= timeout + 2) {
         MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("Status byte timeout!"));
@@ -225,30 +252,38 @@ static unsigned int stepper_center(struct context *cnt, int x_offset, int y_offs
     stepper_command(cnt, cnt->track.motorx, STEPPER_COMMAND_SPEED, cnt->track.speed);
     stepper_command(cnt, cnt->track.motorx, STEPPER_COMMAND_LEFT_N, cnt->track.maxx);
 
-    while (stepper_status(cnt, cnt->track.motorx) & STEPPER_STATUS_LEFT);
+    while (stepper_status(cnt, cnt->track.motorx) & STEPPER_STATUS_LEFT) {
+        continue;
+    }
 
     stepper_command(cnt, cnt->track.motorx, STEPPER_COMMAND_RIGHT_N,
                     cnt->track.maxx / 2 + x_offset * cnt->track.stepsize);
 
-    while (stepper_status(cnt, cnt->track.motorx) & STEPPER_STATUS_RIGHT);
+    while (stepper_status(cnt, cnt->track.motorx) & STEPPER_STATUS_RIGHT) {
+        continue;
+    }
 
     /* y-axis */
 
     stepper_command(cnt, cnt->track.motory, STEPPER_COMMAND_SPEED, cnt->track.speed);
     stepper_command(cnt, cnt->track.motory, STEPPER_COMMAND_UP_N, cnt->track.maxy);
 
-    while (stepper_status(cnt, cnt->track.motory) & STEPPER_STATUS_UP)
+    while (stepper_status(cnt, cnt->track.motory) & STEPPER_STATUS_UP) {
+        continue;
+    }
 
     stepper_command(cnt, cnt->track.motory, STEPPER_COMMAND_DOWN_N,
                     cnt->track.maxy / 2 + y_offset * cnt->track.stepsize);
 
-    while (stepper_status(cnt, cnt->track.motory) & STEPPER_STATUS_DOWN);
+
+    while (stepper_status(cnt, cnt->track.motory) & STEPPER_STATUS_DOWN) {
+        continue;
+    }
 
     return cnt->track.move_wait;
 }
 
-static unsigned int stepper_move(struct context *cnt,
-                                 struct coord *cent, struct images *imgs)
+static unsigned int stepper_move(struct context *cnt, struct coord *cent, struct images *imgs)
 {
     unsigned int command = 0, data = 0;
 
@@ -283,7 +318,9 @@ static unsigned int stepper_move(struct context *cnt,
 
     data = data * cnt->track.stepsize / imgs->width;
 
-    if (data) stepper_command(cnt, cnt->track.motorx, command, data);
+    if (data) {
+        stepper_command(cnt, cnt->track.motorx, command, data);
+    }
 
     /* y-axis */
 
@@ -299,8 +336,9 @@ static unsigned int stepper_move(struct context *cnt,
 
     data = data * cnt->track.stepsize / imgs->height;
 
-    if (data)
+    if (data) {
         stepper_command(cnt, cnt->track.motory, command, data);
+    }
 
 
     return cnt->track.move_wait;
@@ -346,8 +384,8 @@ static int servo_open(struct context *cnt)
 }
 
 
-static unsigned int servo_command(struct context *cnt, unsigned int motor,
-                                  unsigned int command, unsigned int data)
+static unsigned int servo_command(struct context *cnt, unsigned int motor
+            , unsigned int command, unsigned int data)
 {
     unsigned char buffer[3];
     time_t timeout = time(NULL);
@@ -368,7 +406,9 @@ static unsigned int servo_command(struct context *cnt, unsigned int motor,
         return 0;
     }
 
-    while (read(cnt->track.dev, buffer, 1) != 1 && time(NULL) < timeout + 1);
+    while (read(cnt->track.dev, buffer, 1) != 1 && time(NULL) < timeout + 1) {
+        continue;
+    }
 
     if (time(NULL) >= timeout + 2) {
         MOTION_LOG(ERR, TYPE_TRACK, NO_ERRNO,_("Status byte timeout!"));
@@ -398,8 +438,8 @@ static unsigned int servo_position(struct context *cnt, unsigned int motor)
  *      Does relative movements to current position.
  *
  */
-static unsigned int servo_move(struct context *cnt, struct coord *cent,
-                               struct images *imgs, unsigned int manual)
+static unsigned int servo_move(struct context *cnt, struct coord *cent
+            , struct images *imgs, unsigned int manual)
 {
     unsigned int command = 0;
     unsigned int data = 0;
@@ -427,10 +467,11 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
 
 
             if ((cnt->track.motorx_reverse && (offset > 0)) ||
-                (!cnt->track.motorx_reverse && (offset < 0)))
+                (!cnt->track.motorx_reverse && (offset < 0))) {
                 command = SERVO_COMMAND_LEFT_N;
-            else
+            } else {
                 command = SERVO_COMMAND_RIGHT_N;
+            }
 
             data = abs(offset);
 
@@ -453,10 +494,11 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
             offset = cent->y * cnt->track.stepsize;
 
             if ((cnt->track.motory_reverse && (offset > 0)) ||
-                (!cnt->track.motory_reverse && (offset < 0)))
+                (!cnt->track.motory_reverse && (offset < 0))) {
                 command = SERVO_COMMAND_UP_N;
-            else
+            } else {
                 command = SERVO_COMMAND_DOWN_N;
+            }
 
             data = abs(offset);
 
@@ -478,19 +520,21 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
 
         /* Move left */
         if (cent->x < imgs->width / 2) {
-            if (cnt->track.motorx_reverse)
+            if (cnt->track.motorx_reverse) {
                 command = SERVO_COMMAND_RIGHT_N;
-            else
+            } else {
                 command = SERVO_COMMAND_LEFT_N;
+            }
             data = imgs->width / 2 - cent->x;
         }
 
         /* Move right */
         if (cent->x > imgs->width / 2) {
-            if (cnt->track.motorx_reverse)
+            if (cnt->track.motorx_reverse) {
                 command = SERVO_COMMAND_LEFT_N;
-            else
+            } else {
                 command = SERVO_COMMAND_RIGHT_N;
+            }
             data = cent->x - imgs->width / 2;
         }
 
@@ -528,19 +572,21 @@ static unsigned int servo_move(struct context *cnt, struct coord *cent,
 
         /* Move down */
         if (cent->y < imgs->height / 2) {
-            if (cnt->track.motory_reverse)
+            if (cnt->track.motory_reverse) {
                 command = SERVO_COMMAND_UP_N;
-            else
+            } else {
                 command = SERVO_COMMAND_DOWN_N;
+            }
             data = imgs->height / 2 - cent->y;
         }
 
         /* Move up */
         if (cent->y > imgs->height / 2) {
-            if (cnt->track.motory_reverse)
+            if (cnt->track.motory_reverse) {
                 command = SERVO_COMMAND_DOWN_N;
-            else
+            } else {
                 command = SERVO_COMMAND_UP_N;
+            }
             data = cent->y - imgs->height / 2;
         }
 
@@ -616,10 +662,11 @@ static unsigned int servo_center(struct context *cnt, int x_offset, int y_offset
         ,cnt->track.stepsize);
 
     /* x-axis */
-    if (cnt->track.motorx_reverse)
+    if (cnt->track.motorx_reverse) {
         x_offset_abs = (128 - cnt->track.homex) - (x_offset * cnt->track.stepsize) + 128;
-    else
+    } else {
         x_offset_abs = cnt->track.homex + (x_offset * cnt->track.stepsize);
+    }
 
     if (x_offset_abs <= cnt->track.maxx  && x_offset_abs >= cnt->track.minx) {
         /* Set Speed , TODO : it should be done only when speed changes */
@@ -628,10 +675,11 @@ static unsigned int servo_center(struct context *cnt, int x_offset, int y_offset
     }
 
     /* y-axis */
-    if (cnt->track.motory_reverse)
+    if (cnt->track.motory_reverse) {
         y_offset_abs = (128 - cnt->track.homey) - (y_offset * cnt->track.stepsize) + 128;
-    else
+    } else {
         y_offset_abs = cnt->track.homey + (y_offset * cnt->track.stepsize);
+    }
 
     if (y_offset_abs <= cnt->track.maxy && y_offset_abs >= cnt->track.minx) {
         /* Set Speed , TODO : it should be done only when speed changes */
@@ -654,11 +702,14 @@ static char iomojo_command(struct context *cnt, char *command, int len, unsigned
     char buffer[1];
     time_t timeout = time(NULL);
 
-    if (write(cnt->track.dev, command, len) != len)
+    if (write(cnt->track.dev, command, len) != len) {
         return 0;
+    }
 
     if (ret) {
-        while (read(cnt->track.dev, buffer, 1) != 1 && time(NULL) < timeout + 2);
+        while (read(cnt->track.dev, buffer, 1) != 1 && time(NULL) < timeout + 2) {
+            continue;
+        }
 
         if (time(NULL) >= timeout + 2) {
             MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("Return byte timeout!"));
@@ -677,8 +728,9 @@ static void iomojo_setspeed(struct context *cnt, unsigned int speed)
     command[1] = cnt->track.iomojo_id;
     command[2] = speed;
 
-    if (iomojo_command(cnt, command, 3, 1) != IOMOJO_SETSPEED_RET)
+    if (iomojo_command(cnt, command, 3, 1) != IOMOJO_SETSPEED_RET) {
         MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO,_("Unable to set camera speed"));
+    }
 }
 
 static void iomojo_movehome(struct context *cnt)
@@ -736,11 +788,13 @@ static unsigned int iomojo_center(struct context *cnt, int x_offset, int y_offse
             y_offset *= -1;
         }
 
-        if (x_offset > 180)
+        if (x_offset > 180) {
             x_offset = 180;
+        }
 
-        if (y_offset > 60)
+        if (y_offset > 60) {
             y_offset = 60;
+        }
 
         command[0] = IOMOJO_MOVEOFFSET_CMD;
         command[1] = cnt->track.iomojo_id;
@@ -755,17 +809,18 @@ static unsigned int iomojo_center(struct context *cnt, int x_offset, int y_offse
     return cnt->track.move_wait;
 }
 
-static unsigned int iomojo_move(struct context *cnt, int dev, struct coord *cent,
-                                      struct images *imgs)
+static unsigned int iomojo_move(struct context *cnt, int dev, struct coord *cent, struct images *imgs)
 {
     char command[5];
     int direction = 0;
     int nx = 0, ny = 0;
     int i;
 
-    if (dev < 0)
-        if (!iomojo_center(cnt, 0, 0))
+    if (dev < 0) {
+        if (!iomojo_center(cnt, 0, 0)) {
             return 0;
+        }
+    }
 
     if (cent->x < imgs->width / 2) {
         direction |= IOMOJO_DIRECTION_LEFT;
@@ -791,11 +846,13 @@ static unsigned int iomojo_move(struct context *cnt, int dev, struct coord *cent
     ny = ny * 72 / imgs->height;
 
     if (nx || ny) {
-        if (nx > 180)
+        if (nx > 180) {
             nx = 180;
+        }
 
-        if (ny > 60)
+        if (ny > 60) {
             ny = 60;
+        }
 
         command[0] = IOMOJO_MOVEOFFSET_CMD;
         command[1] = cnt->track.iomojo_id;
@@ -805,10 +862,11 @@ static unsigned int iomojo_move(struct context *cnt, int dev, struct coord *cent
         iomojo_command(cnt, command, 5, 0);
 
         /* Number of frames to skip while moving */
-        if (ny >= nx)
+        if (ny >= nx) {
             i = 25 * ny / 90;
-        else
+        } else {
             i = 25 * nx / 90;
+        }
         return i;
     }
 
@@ -851,17 +909,20 @@ static unsigned int lqos_center(struct context *cnt, int dev, int x_angle, int y
         cnt->track.maxy = pmr.tilt_max;
     }
 
-    if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1)
+    if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1) {
         MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
             ,_("ioctl VIDIOCPWCMPTGANGLE"));
+    }
 
     pma.absolute = 1;
 
-    if (x_angle * 100 < cnt->track.maxx && x_angle * 100 > cnt->track.minx)
+    if (x_angle * 100 < cnt->track.maxx && x_angle * 100 > cnt->track.minx) {
         pma.pan = x_angle * 100;
+    }
 
-    if (y_angle * 100 < cnt->track.maxy && y_angle * 100 > cnt->track.miny)
+    if (y_angle * 100 < cnt->track.maxy && y_angle * 100 > cnt->track.miny) {
         pma.tilt = y_angle * 100;
+    }
 
     if (ioctl(dev, VIDIOCPWCMPTSANGLE, &pma) == -1) {
         MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
@@ -874,8 +935,8 @@ static unsigned int lqos_center(struct context *cnt, int dev, int x_angle, int y
     return cnt->track.move_wait;
 }
 
-static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent,
-                                    struct images *imgs, unsigned int manual)
+static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent
+            , struct images *imgs, unsigned int manual)
 {
     int delta_x = cent->x - (imgs->width / 2);
     int delta_y = cent->y - (imgs->height / 2);
@@ -885,11 +946,12 @@ static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent,
 
     /* If we are on auto track we calculate delta, otherwise we use user input in degrees times 100 */
     if (!manual) {
-        if (delta_x > imgs->width * 3/8 && delta_x < imgs->width * 5/8)
+        if (delta_x > imgs->width * 3/8 && delta_x < imgs->width * 5/8) {
             return 0;
-        if (delta_y > imgs->height * 3/8 && delta_y < imgs->height * 5/8)
+        }
+        if (delta_y > imgs->height * 3/8 && delta_y < imgs->height * 5/8) {
             return 0;
-
+        }
         move_x_degrees = delta_x * cnt->track.step_angle_x * 100 / (imgs->width / 2);
         move_y_degrees = -delta_y * cnt->track.step_angle_y * 100 / (imgs->height / 2);
     } else {
@@ -912,26 +974,31 @@ static unsigned int lqos_move(struct context *cnt, int dev, struct coord *cent,
     }
 
     /* Get current camera position */
-    if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1)
+    if (ioctl(dev, VIDIOCPWCMPTGANGLE, &pma) == -1) {
         MOTION_LOG(ERR, TYPE_TRACK, SHOW_ERRNO
             ,_("ioctl VIDIOCPWCMPTGANGLE"));
+    }
 
 
     /*
      * Check current position of camera and see if we need to adjust
      * values down to what is left to move
      */
-    if (move_x_degrees < 0 && (cnt->track.minx - pma.pan) > move_x_degrees)
+    if (move_x_degrees < 0 && (cnt->track.minx - pma.pan) > move_x_degrees) {
         move_x_degrees = (cnt->track.minx - pma.pan);
+    }
 
-    if (move_x_degrees > 0 && (cnt->track.maxx - pma.pan) < move_x_degrees)
+    if (move_x_degrees > 0 && (cnt->track.maxx - pma.pan) < move_x_degrees) {
         move_x_degrees = (cnt->track.maxx - pma.pan);
+    }
 
-    if (move_y_degrees < 0 && (cnt->track.miny - pma.tilt) > move_y_degrees)
+    if (move_y_degrees < 0 && (cnt->track.miny - pma.tilt) > move_y_degrees) {
         move_y_degrees = (cnt->track.miny - pma.tilt);
+    }
 
-    if (move_y_degrees > 0 && (cnt->track.maxy - pma.tilt) < move_y_degrees)
+    if (move_y_degrees > 0 && (cnt->track.maxy - pma.tilt) < move_y_degrees) {
         move_y_degrees = (cnt->track.maxy - pma.tilt);
+    }
 
     /* Move camera relative to current position */
     pma.absolute = 0;
@@ -1040,11 +1107,13 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
         ,_("INPUT_PARAM_ABS X_Angel %d, Y_Angel %d ")
         ,x_angle, y_angle);
 
-    if (x_angle <= cnt->track.maxx && x_angle >= cnt->track.minx)
+    if (x_angle <= cnt->track.maxx && x_angle >= cnt->track.minx) {
         move_x_degrees = x_angle - (cnt->track.pan_angle);
+    }
 
-    if (y_angle <= cnt->track.maxy && y_angle >= cnt->track.miny)
+    if (y_angle <= cnt->track.maxy && y_angle >= cnt->track.miny) {
         move_y_degrees = y_angle - (cnt->track.tilt_angle);
+    }
 
 
     /*
@@ -1077,8 +1146,9 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
     }
 
     /* DWe 30.03.07 We must wait a little,before we set the next CMD, otherwise PAN is mad ... */
-    if ((move_x_degrees != 0) && (move_y_degrees != 0))
+    if ((move_x_degrees != 0) && (move_y_degrees != 0)) {
         SLEEP(1, 0);
+    }
 
     if (move_y_degrees != 0) {
         control_s.id = V4L2_CID_TILT_RELATIVE;
@@ -1115,8 +1185,8 @@ static unsigned int uvc_center(struct context *cnt, int dev, int x_angle, int y_
     return cnt->track.move_wait;
 }
 
-static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
-                                   struct images *imgs, unsigned int manual)
+static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent
+            , struct images *imgs, unsigned int manual)
 {
     /* RELATIVE MOVING : Act.Position +/- X and Y */
 
@@ -1179,11 +1249,12 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
 
     /* If we are on auto track we calculate delta, otherwise we use user input in degrees */
     if (!manual) {
-        if (delta_x > imgs->width * 3/8 && delta_x < imgs->width * 5/8)
+        if (delta_x > imgs->width * 3/8 && delta_x < imgs->width * 5/8) {
             return 0;
-        if (delta_y > imgs->height * 3/8 && delta_y < imgs->height * 5/8)
+        }
+        if (delta_y > imgs->height * 3/8 && delta_y < imgs->height * 5/8) {
             return 0;
-
+        }
         move_x_degrees = delta_x * cnt->track.step_angle_x / (imgs->width / 2);
         move_y_degrees = -delta_y * cnt->track.step_angle_y / (imgs->height / 2);
     } else {
@@ -1207,17 +1278,21 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
      * Check current position of camera and see if we need to adjust
      * values down to what is left to move
      */
-        if (move_x_degrees < 0 && (cnt->track.minx - cnt->track.pan_angle) > move_x_degrees)
+        if (move_x_degrees < 0 && (cnt->track.minx - cnt->track.pan_angle) > move_x_degrees) {
             move_x_degrees = cnt->track.minx - cnt->track.pan_angle;
+        }
 
-        if (move_x_degrees > 0 && (cnt->track.maxx - cnt->track.pan_angle) < move_x_degrees)
+        if (move_x_degrees > 0 && (cnt->track.maxx - cnt->track.pan_angle) < move_x_degrees) {
             move_x_degrees = cnt->track.maxx - cnt->track.pan_angle;
+        }
 
-        if (move_y_degrees < 0 && (cnt->track.miny - cnt->track.tilt_angle) > move_y_degrees)
+        if (move_y_degrees < 0 && (cnt->track.miny - cnt->track.tilt_angle) > move_y_degrees) {
             move_y_degrees = cnt->track.miny - cnt->track.tilt_angle;
+        }
 
-        if (move_y_degrees > 0 && (cnt->track.maxy - cnt->track.tilt_angle) < move_y_degrees)
+        if (move_y_degrees > 0 && (cnt->track.maxy - cnt->track.tilt_angle) < move_y_degrees) {
             move_y_degrees = cnt->track.maxy - cnt->track.tilt_angle;
+        }
     }
 
     MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
@@ -1261,8 +1336,9 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
     }
 
     /* DWe 30.03.07 We must wait a little,before we set the next CMD, otherwise PAN is mad ... */
-    if ((move_x_degrees != 0) && (move_y_degrees != 0))
+    if ((move_x_degrees != 0) && (move_y_degrees != 0)) {
         SLEEP (1, 0);
+    }
 
 
     if (move_y_degrees != 0) {
@@ -1289,11 +1365,13 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
             ,_("Before_REL_Y_Angel : x= %d , Y= %d")
             ,cnt->track.pan_angle, cnt->track.tilt_angle);
 
-        if (move_x_degrees != 0)
+        if (move_x_degrees != 0) {
             cnt->track.pan_angle += -pan.s16.pan / INCPANTILT;
+        }
 
-        if (move_y_degrees != 0)
+        if (move_y_degrees != 0) {
             cnt->track.tilt_angle += -pan.s16.tilt / INCPANTILT;
+        }
 
         MOTION_LOG(DBG, TYPE_TRACK, NO_ERRNO
             ,_("After_REL_Y_Angel : x= %d , Y= %d")
@@ -1304,8 +1382,8 @@ static unsigned int uvc_move(struct context *cnt, int dev, struct coord *cent,
 }
 #endif /* HAVE_V4L2 */
 
-static unsigned int generic_move(struct context *cnt, enum track_action action, unsigned int manual,
-                                 int xoff, int yoff, struct coord *cent, struct images *imgs)
+static unsigned int generic_move(struct context *cnt, enum track_action action
+            , unsigned int manual, int xoff, int yoff, struct coord *cent, struct images *imgs)
 {
     char fmtcmd[PATH_MAX];
     cnt->track_posx += cent->x;
@@ -1321,8 +1399,9 @@ static unsigned int generic_move(struct context *cnt, enum track_action action,
         setsid();
 
         /* Provides data as environment variables */
-        if (manual)
+        if (manual) {
           setenv("TRACK_MANUAL", "manual", 1);
+        }
         switch (action) {
           case TRACK_CENTER:
             setenv("TRACK_ACTION", "center", 1);
@@ -1352,8 +1431,9 @@ static unsigned int generic_move(struct context *cnt, enum track_action action,
          * Close any file descriptor except console because we will
          * like to see error messages
          */
-        for (i = getdtablesize() - 1; i > 2; i--)
+        for (i = getdtablesize() - 1; i > 2; i--) {
             close(i);
+        }
 
         execl("/bin/sh", "sh", "-c", fmtcmd, " &", NULL);
 
